--[[ *** Used to create all the controls *** ]]--

--[[ anchor - position , relative position , offsetX , offsetY
 	 dimensions - x , y
 	 color - Red , Green , Blue , Alpha
 	 align - horizontalAlignment , verticalAlignment
]]--

function rgbFix(IN)
	local color = {}
	color[1] = IN[1]/255
	color[2] = IN[2]/255
	color[3] = IN[3]/255
	color[4] = IN[4]
	
	return color
end

-- Creates top level window
function WG.UI.TopLevelWindow ( name , parent , dimensions , anchor , hidden , table1 , table2 )
	if ( name == "" or name == nil ) then return end
	parent = ( parent == nil ) and GuiRoot or parent
	hidden = ( hidden == nil ) and false or hidden
	
	local frame = WINDOW_MANAGER:CreateTopLevelWindow ( name )
		frame:SetDimensions   ( dimensions[1] , dimensions[2] )
		frame:SetAnchor       ( anchor[1] , parent , anchor[2] , anchor[3] , anchor[4] )
		frame:SetHidden       ( hidden )
		frame:SetMovable      ( true )
		frame:SetMouseEnabled ( true )
		frame:SetHandler      ( "OnMoveStop" , function ( self ) WG.OnMoveStop ( self , table1 , table2 ) end )
		
	return frame
end

-- Creates Control
function WG.UI.Control ( name , parent , dimensions , anchor , hidden  )
	
	if ( name == "" or name == nil ) then return end
	parent = ( parent == nil ) and GuiRoot or parent
	hidden = ( hidden == nil ) and false or hidden
	
	local control = WINDOW_MANAGER:CreateControl( name , parent , CT_CONTROL )
		control:SetDimensions ( dimensions[1] , dimensions[2] )
		control:SetAnchor     ( anchor[1] , parent , anchor[2] , anchor[3] , anchor[4] )
		control:SetHidden     ( hidden )
		
	return control
end

-- Creates Label
function WG.UI.Label ( name , parent , dimensions , anchor , align , font , color , text , hidden )
	if ( name == "" or name == nil ) then return end
	parent = ( parent == nil ) and GuiRoot or parent
	hidden = ( hidden == nil ) and false or hidden
	font   = ( font == nil )   and "ZoFontAnnounceSmall" or font
	color  = ( color == nil )  and { 1 , 1 , 1 , 1 } or color
	
	local label = WINDOW_MANAGER:CreateControl ( name , parent , CT_LABEL )
		label:SetDimensions          ( dimensions[1] , dimensions[2] )
		label:SetAnchor              ( anchor[1] , parent , anchor[2] , anchor[3] , anchor[4] )
		label:SetFont                ( font )
		label:SetColor               ( color[1] , color[2] , color[3] , color[4] )
		label:SetHorizontalAlignment ( align[1] )
		label:SetVerticalAlignment   ( align[2] )
		label:SetText 			     ( text )
		label:SetHidden 		     ( hidden )
		
	return label
end

-- Creates Statusbar
function WG.UI.Statusbar ( name , parent , dimensions , anchor , color , hidden )
	if ( name == "" or name == nil ) then return end
	parent = ( parent == nil ) and GuiRoot or parent
	hidden = ( hidden == nil ) and false or hidden
	color = ( color == nil )   and { 1 , 1 , 1 , 1 } or color
	
	local sBar = WINDOW_MANAGER:CreateControl ( name , parent , CT_STATUSBAR )
		sBar:SetDimensions ( dimensions[1] , dimensions[2] )
		sBar:SetAnchor     ( anchor[1] , parent , anchor[2] , anchor[3] , anchor[4] )
		sBar:SetColor      ( color[1] , color[2] , color[3] , color[4] )
		sBar:SetHidden     ( hidden )
		sBar:SetMinMax     ( 0 , 100 )
		
	return sBar
end

-- Creates Backdrop
function WG.UI.Backdrop ( name , parent , dimensions , anchor , center , edge , hidden )
	if ( name == "" or name == nil ) then return end
	parent = ( parent == nil ) and GuiRoot or parent
	hidden = ( hidden == nil )  and false or hidden
	center = ( center == nil ) and { 1 , 1 , 1 , 1 } or rgbFix ( center )
	edge =   ( edge == nil )   and { 1 , 1 , 1 , 1 } or rgbFix ( edge )
	
	local backDrop = WINDOW_MANAGER:CreateControl ( name , parent , CT_BACKDROP )
		backDrop:SetDimensions  ( dimensions[1] , dimensions[2] )
		backDrop:SetAnchor      ( anchor[1] , parent , anchor[2] , anchor[3] , anchor[4] )
		backDrop:SetCenterColor ( center[1] , center[2] , center[3] , center[4] )
		backDrop:SetEdgeColor   ( edge[1] , edge[2] , edge[3] , edge[4] )
		backDrop:SetHidden      ( hidden )
	
	return backDrop
end

function WG.UI.Texture ( name , parent , dimensions , anchor , texture , hidden )
	if ( name == "" or name == nil or texture == nil ) then return end
	parent = ( parent == nil ) and GuiRoot or parent
	hidden = ( hidden == nil ) and false or hidden
	
	local textureCT = WINDOW_MANAGER:CreateControl ( name , parent , CT_TEXTURE )
		textureCT:SetDimensions ( dimensions[1] , dimensions[2] )
		textureCT:SetAnchor     ( anchor[1] , parent , anchor[2] , anchor[3] , anchor[4] )
		textureCT:SetTexture    ( texture )
		textureCT:SetHidden     ( hidden )
		
	return textureCT
end